--[[
    Modular HUD Loader

    This script is used to load the Modular HUD.

        @author:    BayernGamers
        @date:      26.12.2024
        @version:   2.0

        History:    v1.0 @17.12.2023 - initial implementation in FS 22
                    -------------------------------------------------------------------------------------------
                    v2.0 @26.12.2024 - convert to FS 25

        License:    Terms:
                        Usage:
                            Feel free to use this work as-is as long as you adhere to the following terms:
                        Attribution:
                            You must give appropriate credit to the original author when using this work.
                        No Derivatives:
                            You may not alter, transform, or build upon this work in any way.
                        Usage:
                            The work may be used for personal and commercial purposes, provided it is not modified or adapted.
                        Additional Clause:
                            This script may not be converted, adapted, or incorporated into any other game versions or platforms except by GIANTS Software.
]]

source(Utils.getFilename("scripts/utils/LoggingUtil.lua", g_currentModDirectory))
source(Utils.getFilename("scripts/utils/ModularHUDUtil.lua", g_currentModDirectory))
source(Utils.getFilename("scripts/ModularHUDModFixes.lua", g_currentModDirectory))
source(Utils.getFilename("scripts/ModularHUD.lua", g_currentModDirectory))
source(Utils.getFilename("scripts/ModularHUDSettings.lua", g_currentModDirectory))
source(Utils.getFilename("scripts/ModSettingsManager.lua", g_currentModDirectory))
source(Utils.getFilename("scripts/interface/ModularHUDInterface.lua", g_currentModDirectory))

local log = LoggingUtil.new(true, LoggingUtil.DEBUG_LEVELS.HIGH, "ModularHUD.lua")

--- Modular HUD Loader
-- Contains functions to initialize and manage the Modular HUD.
-- @classmod      ModularHUDLoader
-- @field      debugLevel number The debug level for logging.
-- @field      debugLevelHigh number The high debug level for logging.
-- @field      MOD_DIRECTORY string The directory of the mod.
-- @field      MOD_NAME string The name of the mod.
-- @field      MOD_SETTINGS_DIRECTORY string The directory for mod settings.
ModularHUDLoader = {}

ModularHUDLoader.debugLevel = 1
ModularHUDLoader.debugLevelHigh = 2
ModularHUDLoader.MOD_DIRECTORY = g_currentModDirectory;
ModularHUDLoader.MOD_NAME = g_currentModName;
ModularHUDLoader.MOD_SETTINGS_DIRECTORY = g_currentModSettingsDirectory;

-- Check if script is running on dedicated server
local isDedi = g_dedicatedServer ~= nil

if isDedi then
    log:printDevInfo("Running on dedicated server, skipping script", ModularHUDLoader.debugLevelHigh)
    return
end

-- Initialized ModularHUD settings
ModularHUDSettings.init()