--[[
ModularHUDModFixes

AdditionalCams fixes for the custom HUD Toggle in 3rd party mods

	@author: 	BayernGamers
	@date: 		26.12.2024
	@version:	2.0

	History:	v1.0 @17.12.2023 - initial implementation in FS22
				-------------------------------------------------------------------------------------------
                v2.0 @26.12.2024 - convert to FS25

    License:    Terms:
                    Usage:
                        Feel free to use this work as-is as long as you adhere to the following terms:
                    Attribution:
                        You must give appropriate credit to the original author when using this work.
                    No Derivatives:
                        You may not alter, transform, or build upon this work in any way.
                    Usage:
                        The work may be used for personal and commercial purposes, provided it is not modified or adapted.
                    Additional Clause:
                        This script may not be converted, adapted, or incorporated into any other game versions or platforms except by GIANTS Software.
]]

source(Utils.getFilename("scripts/utils/LoggingUtil.lua", g_currentModDirectory))
source(Utils.getFilename("scripts/utils/ModularHUDUtil.lua", g_currentModDirectory))

local log = LoggingUtil.new(true, LoggingUtil.DEBUG_LEVELS.HIGH, "ModularHUDModFixes.lua")

--- Modular HUD Mod Fixes
-- Contains functions to apply fixes and overwrites to other mod specializations and classes.
-- @classmod      ModularHUDModFixes
-- @field      debugLevel number The debug level for logging.
-- @field      debugLevelHigh number The high debug level for logging.
-- @field      MOD_DIRECTORY string The directory of the mod.
-- @field      MOD_NAME string The name of the mod.
-- @field      MOD_SETTINGS_DIRECTORY string The directory for mod settings.
ModularHUDModFixes = {}

ModularHUDModFixes.debugLevel = 1
ModularHUDModFixes.debugLevelHigh = 2
ModularHUDModFixes.MOD_DIRECTORY = g_currentModDirectory;
ModularHUDModFixes.MOD_NAME = g_currentModName;
ModularHUDModFixes.MOD_SETTINGS_DIRECTORY = g_currentModSettingsDirectory;

local isDedi = g_dedicatedServer ~= nil

if isDedi then
    log:printDevInfo("Running on dedicated server, skipping script", ModularHUDModFixes.debugLevelHigh)
    return
end

--- Function to overwrite functions in specializations.
-- @return     void
function ModularHUDModFixes:overwriteSpecializationParts()
    -- Enhanced Vehicle
    if FS25_EnhancedVehicle ~= nil and FS25_EnhancedVehicle.FS25_EnhancedVehicle ~= nil and FS25_EnhancedVehicle.FS25_EnhancedVehicle.onDraw ~= nil and FS25_EnhancedVehicle.FS25_EnhancedVehicle_HUD.drawHUD ~= nil then
        FS25_EnhancedVehicle.FS25_EnhancedVehicle.onDraw = ModularHUDUtil.tachometerVisibilityConditionalFunction(FS25_EnhancedVehicle.FS25_EnhancedVehicle.onDraw)
        FS25_EnhancedVehicle.FS25_EnhancedVehicle_HUD.drawHUD = ModularHUDUtil.tachometerVisibilityConditionalFunction(FS25_EnhancedVehicle.FS25_EnhancedVehicle_HUD.drawHUD)
    end

    for vehicleTypeName, vehicleType in pairs(g_vehicleTypeManager.types) do
        -- Park Vehicle
        local parkVehicleKey = "FS25_parkVehicle.parkVehicle"
        if vehicleType.specializationsByName[parkVehicleKey] ~= nil then
            vehicleType.specializationsByName[parkVehicleKey].onDraw = ModularHUDUtil.tachometerVisibilityConditionalFunction(vehicleType.specializationsByName[parkVehicleKey].onDraw)
        end
    end
end

FSBaseMission.loadMapFinished = Utils.appendedFunction(FSBaseMission.loadMapFinished, ModularHUDModFixes.overwriteSpecializationParts)

--- Overwrite Functions in Non-Specialization Classes.
-- @return     void
function ModularHUDModFixes:overwriteNonSpecializationClasses()
    if --[[ g_modIsLoaded["MODFILENAME"] ]] true then
        for i, listenerI in ipairs(g_modEventListeners) do
            local classname = ModularHUDUtil.getClassName(listenerI)
            --[[
            if classname == "MODFILENAME.CLASS" then
                listenerI.draw = ModularHUDUtil.gameInfoVisibilityConditionalFunction(listenerI.drawFunction)
            end
            ]]
        end
    end
end

FSBaseMission.loadMapFinished = Utils.appendedFunction(FSBaseMission.loadMapFinished, ModularHUDModFixes.overwriteNonSpecializationClasses)